module Example.Goose.View exposing (..)


import Svg exposing (..)
import Svg.Attributes exposing (..)
import Svg.Attributes as SA exposing (style)


import Example.Goose.Model exposing (..)
import Example.Goose.Msg exposing (..)
import Color exposing (Color)


view : Model -> Svg msg
view model =
    svg
        [ id "goose"
        , viewBox "0 0 662.2 671.4"
        , preserveAspectRatio "xMidYMid meet"
        , x "0", y "0"
        , width "100%"
        -- , height "711px"
        , height "100vh"
        , version "1.1"
        , SA.style <| "background-color: "
            ++ Color.toCssString model.colors.background
        ]
        [ body
            model.colors
            model.lookAt
            ( model.punk, model.colors.iroquois )
        , head
            model.colors
            model.lookAt
            (Tuple.first model.honk)
            model.eye
        , if Tuple.first model.honk
            then honk <| Tuple.second model.honk
            else Svg.g [] []
        , case model.shoes of
            None -> Svg.g [] []
            Boots -> boots
        ]


body : Colors -> LookDirection -> ( Bool, Color ) -> Svg msg
body colors dir ( isPunk, iroquoisColor ) =
    g
        [ id "body"
        ]
        [ if isPunk
            then iroquois colors.iroquois dir
            else Svg.g [] []
        , rightLeg colors.skin
        , leftLeg colors.skin
        , chest colors.feathers
        ]


head : Colors -> LookDirection -> Bool -> EyeConfig -> Svg msg
head colors dir honkOn eyeConfig =
    g
        [ id "head"
        , SA.style
            <| case dir of
                Left -> "transform: translateX(0) scaleX(1)"
                Right -> "transform: translateX(519.8px) scaleX(-1)"
        ]
        [ neck colors.feathers
        , beak colors.skin
        , if honkOn then openBeak colors.skin else Svg.g [] []
        , eye ( colors.eye, eyeConfig )
        ]


iroquois : Color -> LookDirection -> Svg msg
iroquois color dir =
    polygon
        [ id "iro"
        , fill <| Color.toCssString color
        , SA.style
            <| case dir of
                Left -> ""
                Right -> "transform: translateX(519.8px) scaleX(-1)"
        , points "289.8,62.5 304.8,62.5 287.8,77.4 245.1,67.9 215.9,65.5 177.2,36.4 202.3,40.2 194.5,22 213.4,33.9 213.4,29.2 205.7,12.3 213.4,19.1 213.4,8.9 224.6,22.5 227.1,12.3 235.9,23.9 235.9,3.6 241.8,20.3 248.4,3.7 252.6,27.2 261.2,3.6 262,22.6 275.3,12.5 275.3,29.7 293.7,9.4 284.1,41.1 293.4,38.5 291.5,44.5 304.8,37.8"
        ]
        [ ]


rightLeg : Color -> Svg msg
rightLeg color =
    Svg.path
        [ id "rleg"
        , class "skin"
        , fill <| Color.toCssString color
        , d "M373.6 592.7c-4.7-9.5-8.7-19.4-13-29.2v-2.6-1.6c.2-1.8.6-3.6.8-5.3.4-2.6.8-5.1 1.4-7.7 3-14.6 6.1-29 9.1-43.5.6-2.2 1.2-4.3 1.8-6.5-2.8.6-5.9 1-8.7 1.6h-3.2c-1.4-.6-2.6-1.4-4.1-2-.8 4.3-1.6 8.3-2.4 12.6-.6 5.3-1 10.5-1.6 15.6-.4 1.8-.6 3.6-1 5.5-2.6 8.3-5.1 16.4-7.7 24.7-.6.8-1.2 1.4-1.8 2.2-3.6 2.4-7.1 5.5-11.1 7.3-13.6 6.3-27.3 12.2-40.9 18.2-.6.4-1 1-1.6 1.4-.4 1.4-.6 2.8-1 4.3 3.8 4.9 9.1 2.6 14 2.4 3.6 0 7.5-.2 11.1-.2-.2-.2-.4-.4-.8-.6.2.2.4.4.8.6 1.2.8 2.4 1.4 3.4 2.4 7.9 9.5 17.4 9.5 27.7 5.1 8.5-3.6 15.6.2 22.7 4.3h4.3c3.2-2.5 3.6-5.1 1.8-9zm-62.8-4.8c.4.2 1 .4 1.4.8-.4-.2-.8-.6-1.4-.8z"
        ]
        [ ]


leftLeg : Color -> Svg msg
leftLeg color =
    Svg.path
        [ id "lleg"
        , class "skin"
        , fill <| Color.toCssString color
        , d "M248.5 463.3c-2.6 0-5.3-.2-7.7-.2 0 1.4-.2 2.8-.2 4.3.2.8.2 1.6.4 2.4 2.2 14.4 2.6 29 1 43.3-.4 2.8-.6 5.7-2 8.3-2.2 4.3-7.5 6.1-11.9 7.5-16 4.5-33 6.7-49.4 9.9-1.8.4-3.6.8-5.3 1.6-5.1 3.2-1.6 6.1 2.2 7.5 2 .8 4.1 1 6.3 1.2 2.8.2 2.2.8 1.2 2.8-3.2 5.7-2 7.9 4.7 8.3 7.9.4 16 .2 23.9.2.4 0 1 .2 1.4.2 3.8 8.1 6.3 9.1 13 5.3 1-.6 1.8-1.4 2.6-2.2 1-.6 1.8-1.2 2.8-1.8 1.4-1 2.8-1.8 4.5-2.8h-.2c1-.6 1.8-1 2.8-1.6 1.4-1 3-1.8 4.5-2.8.6 0 1-.2 1.2-.6.4-.4.8-.6 1.2-1 .6-.4 1-.8 1.6-1.2.8-.6 1.8-1.2 2.6-1.8.6-.4 1-.8 1.6-1.2 1.2-1 2.4-1.8 3.6-2.8.6-.6 1.2-1.2 2-1.8.6-.8 1.2-1.8 1.8-2.6.4-.6.6-1.2 1-1.8.4-.2.6-.6.8-1 .4-.2.8-.6.8-1 4.8-2.7 1.3-7.2-.1-11.2 0-.2-.2-.4-.2-.8-2-6.9-2.6-14.8-3.2-21.9-1.2-14.6-.4-29.4 2-43.7-.2.8-9.7 2.4-11.3 3z"
        ]
        [ ]


chest : Color -> Svg msg
chest color =
    Svg.path
        [ id "chest"
        , fill <| Color.toCssString color
        , d "M303.2 242.8c-4.3-1.5-6.9-3.1-8.1-6.1h-70.3c-2 4.7-4.2 9.3-6.5 13.8-3.2 6.1-7.9 11.3-11.5 17.4-4.1 6.9-7.7 14-10.9 21.3-6.1 14.8-8.7 30.6-4.5 46.2 3.8 14.4 8.9 28.8 14.8 42.5 7.5 17.6 11.7 35.8 15.6 54.7 1.8 9.1 7.1 17.8 11.3 26.3 1.2 2.6 4.9 3.8 7.5 5.9 2.6 0 5.3.2 7.7.2 3.8-1 7.5-2.2 11.3-3.2 8.5-4.7 16.4-11.7 25.5-13.6 6.5-1.4 14.6 3.8 21.7 6.7 8.3 3.2 15.2 8.1 21.1 14.8 6.1 6.9 12.8 13.2 19.4 19.4 3 2.8 6.7 5.3 9.9 8.1 1.4.6 2.6 1.4 4.1 2h3.2c2.8-.6 5.9-1 8.7-1.6 10.9-8.1 16.4-20.3 22.3-32 10.5-21.9 21.1-43.5 32-65.2 5.5-10.7 12.2-22.1 13.8-34.4 1.8-13.2 7.9-21.7 15-32.8 9.4-13.7 15.8-32.1 14.6-49-.2-2.4-.8-4.5-1.8-6.3-5.7-10.9-21.3-11.9-31.2-7.7-6.1 2.6-11.9 6.3-18.4 7.7-9.3 2-19-1.2-27.9-4.5-29.5-10.3-58.8-20.5-88.4-30.6"
        ]
        [ ]


neck : Color -> Svg msg
neck color =
    Svg.path
        [ id "chest"
        , fill <| Color.toCssString color
        , d "M295.1 236.7c-.6-1.4-.8-3.2-.8-5.4.2-6.1.4-11.7 0-17.8-.8-14.4-1.4-29-.2-43.5 2-22.3 7.5-45 3.2-67.2-4.3-23.1-22.7-51.8-46.8-58.5-4.9-1.4-9.9-1-14.6.6-6.1 2-11.3 6.1-15.4 10.7S213 66.5 213.4 73l2.4-.6c9.3-2 16.4.4 20.7 9.7 2.8 6.3 6.5 12.4 9.9 18.6-2.2 1.8-3.8 4.7-4.5 8.7.6-4.1 11.9 1.2 13 2.8 7.1 10.9-3 31-5.9 41.7-7.2 27.7-13 56.4-24.3 82.8"
        ]
        [ ]


openBeak : Color -> Svg msg
openBeak color =
    Svg.g
        [ id "mouth"
        ]
        [ Svg.path
            [ class "skin"
            , fill <| Color.toCssString color
            , d "M248.4,103.9c0,0,0.6,7-5.1,12.7c-7.7,7.7-12.3,15.9-16.2,19.8c-4.9,4.7-7.4,6.6-13.6,9.4c-6,2.8-7.8-4-7.8-4 L248.4,103.9z"
            ]
            [ ]
        , Svg.path
            [ class "skin"
            , fill "#ec297b"
            , d "M248.4,103.9c0,0-8,9.9-11.6,13.8c-5.2,5.4-10.7,16-16,20.3c-3.1,2.5-9.2,6.6-12.1,5.5c-2.5-1-4.1-1.1-3.4-4.8c0.7-3.7,2-7.5,2-7.5l20.6-13.6L248.4,103.9z"
            ]
            [ ]
        ]

beak : Color -> Svg msg
beak color =
    Svg.path
        [ id "nose"
        , class "skin"
        , fill <| Color.toCssString color
        , d "M196.4 119.4c5.3-14.2 10.3-28.4 15.6-42.5.4-.6.6-2.6 1.2-3.2.8-.8.6-1 3-1.4 9.3-2 16.4.6 20.7 9.9 3.4 7.5 7.7 14.6 11.5 21.7-6.5 5.7-13 11.5-19.4 17.2-2 2-4.3 3.8-6.3 5.9-8.9 6.1-26.5 4.1-28.2 2.6-3.6-3.5 1.1-6.8 1.9-10.2z"
        ]
        [ ]


eyePos = ( 250.2, 65.5 )


eye : ( Color, EyeConfig ) -> Svg msg
eye ( color, config ) =
    Svg.circle
        [ id "eye"
        , cx
            <| String.fromFloat
            <| case ( eyePos, config.position ) of
                ( ( origX, _ ), ( shiftX, _ ) ) -> origX + shiftX
        , cy
            <| String.fromFloat
            <| case ( eyePos, config.position ) of
                ( ( _, origY ), ( _, shiftY ) ) -> origY + shiftY
        , r <| String.fromFloat config.size
        , fill <| Color.toCssString color
        ]
        [ ]


textPos = ( 420.9966, 82.7509 )


honk : HonkConfig -> Svg msg
honk config =
    Svg.g
        [ id "honk" ]
        [ Svg.path
            [ stroke <| Color.toCssString config.color
            , fill "none"
            , class "bubble"
            , strokeWidth "3"
            , d "M527.2,71.7c0,16.9-12.2,31.8-30.7,40.2c-10.2,4.7-22.4,7.4-35.4,7.4c-22.4,0-42.3-8.1-54.2-20.4l-52.9,5 l42.9-20.8c-1.2-3.7-1.9-7.5-1.9-11.4c0-26.3,29.6-47.7,66.1-47.7C497.6,24,527.2,45.3,527.2,71.7z" ]
            [ ]
        , text_
            [ fontSize <| String.fromInt config.size
            , id "text"
            , transform
                <| case ( textPos, config.position ) of
                    ( ( origX, origY ), ( shiftX, shiftY ) ) ->
                        "matrix(1 0 0 1 "
                            ++ (String.fromFloat <| origX + shiftX) ++ " "
                            ++ (String.fromFloat <| origY + shiftY) ++ ")"
            , fill <| Color.toCssString config.color
            ]
            [ text <| config.text ]
        , line
            [ stroke <| Color.toCssString config.color
            , class "bubble"
            , strokeWidth "3"
            , x1 "494.4", y1 "137"
            , x2 "516.9", y2 "201.5"
            ]
            []
        , line
            [ stroke <| Color.toCssString config.color
            , class "bubble"
            , strokeWidth "3"
            , x1 "531.1", y1 "111.1"
            , x2 "564.1", y2 "143.7"
            ]
            []
        , line
            [ stroke <| Color.toCssString config.color
            , class "bubble"
            , strokeWidth "3"
            , x1 "545.8", y1 "43.4"
            , x2 "582.3", y2 "32.6"
            ]
            []
        , line
            [ stroke <| Color.toCssString config.color
            , class "bubble"
            , strokeWidth "3"
            , x1 "564.1", y1 "82.8"
            , x2 "621.5", y2 "88.2"
            ]
            []
        , line
            [ stroke <| Color.toCssString config.color
            , class "bubble"
            , strokeWidth "3"
            , x1 "443", y1 "143.7"
            , x2 "434.2", y2 "173.5"
            ]
            []
    ]


boots : Svg msg
boots =
    g
        [ id "boots" ]
        [ Svg.style [] [ text " .st0{fill:#FBED52;} .st1{fill:#C89D40;} .st2{fill:#E7DBB8;} .st3{fill:#FDF591;} .st4{fill:#B7A88B;} .st5{fill:#E1C943;} .st6{fill:#F4E34D;} .st7{fill:#FEFEFE;} .st8{fill:#A4813C;} .st9{fill:#DEB254;} .st10{fill:#FFFFFF;} " ]
        , g []
            [ Svg.path [ id "bg", class "st0", d "M224.6,448c0,0,2.6,42,2.6,56.1c0,14-29.3,25.1-29.3,25.1l-32.9,14c0,0-5.5,2.5-6.5,4 c-1.4,2.1-1.3,7.5-1.3,10c0,2.5,13.2,12.1,18.8,13.6c8.8,2.5,27.7,0.4,36.7-1.4c13.5-2.7,63.1-14.9,67.5-29.5 c3.7-12.2,1.5-53.9,1.5-53.9l-1.2-33c0,0-22.3,5.8-29.8,5C243.7,457.3,224.6,448,224.6,448z" ] []
            , Svg.path [ class "st1", d "M228.3,449.5c0,0,0.1,0,0.2,0c0,0.1,0,0.2,0.1,0.3l6.7,1.7h0.4c0.6,0.1,1.2,0.2,1.8,0.4h0.6 c1.1,0.2,2.2,0.3,3.3,0.4h0.7l0.9,0.4h0.8c0.2,0,0.4,0,0.7,0h1.1c0.4,0.1,0.7,0.2,1.1,0.4h1.7c0.5,0,1,0,1.5,0h8.7 c0.8,0,1.6,0,2.4,0l0.9-0.4c0.4-0.1,0.9-0.2,1.3-0.2c0.5,0,1.1,0.2,1.6,0.1c2.8-0.4,5.5-0.7,8.3-1.2c1.3-0.2,2.7-0.3,3.9-0.7 c1.9-0.5,3.7-1.2,5.5-1.9c0.1,0.8,0.3,1.7,0.4,2.5c0.1,0.9,0.1,3.4,0.1,3.4c-1.6,0.5-3.1,0.9-4.7,1.3c-1.7,0.5-3.4,0.9-5.1,1.3 c-6.1,1.4-19.8,1.4-20.4,1.3c-4.1-0.4-8.1-0.9-12.1-1.3c-3.9-0.4-7.8-1.5-11.4-2.9c-1.5-0.6-2.7-1.9-4.2-2.7l-0.4-0.8 c0-1-0.1-2-0.2-3l0.3-5.6" ] []
            , Svg.path [ class "st2", d "M186.6,567.4c0,1.3-1.2,1.3-2,1.4c-1.2,0.2-2.3,0.2-3.6,0.2c-0.8,0-1.6-0.1-1.7,0.7c-0.2,1.1-1.2,1.2-2.1,1.4 c-0.1,0-0.3,0-0.4,0c-0.3-0.1-0.6-0.2-0.9-0.3c-0.1,0-0.3,0-0.4-0.1c-0.7-0.3-1.4-0.8-2.1-1c-3.3-1-6.3-2.5-9-4.4 c-3.1-2.3-5.5-5-7.4-8.2c-0.1-0.1-0.1-0.3-0.2-0.4c-0.3-0.2-0.7-0.3-1-0.4c-0.1,0.3-0.3,0.6-0.2,0.8c0.5,1.2,0.9,2.6,1.6,3.7 c2.2,3.6,5.5,6.3,9.3,8.3c3.4,1.7,6.9,3,10.5,4.5c0.6,0.2,0.7,0.4,0.7,1.1c-0.2,1.4-0.2,2.8-0.3,4.2c-3.1-1.2-6.4-2.2-9.4-3.7 c-4.1-2-7.4-4.8-9.9-8.3c-2.7-3.7-4.1-7.9-3.4-12.4c0.4-2.5,1.2-5,3-7c0.2,1,0.6,1.9,0.6,2.8c0,2.4,0.5,4.7,2,6.8 c1.8,2.6,4.1,4.7,6.9,6.2c4.4,2.4,9.3,3.5,14.5,3.6C183.2,567,184.9,567.2,186.6,567.4z" ] []
            , Svg.path [ class "st3", d "M186.6,567.4c-1.7-0.2-3.4-0.4-5.1-0.4c-5.1-0.1-10-1.2-14.5-3.6c-2.8-1.5-5.1-3.6-6.9-6.2 c-1.5-2.1-1.9-4.3-2-6.8c0-1-0.4-1.9-0.6-2.8c0.3-1,0.7-2,1.7-2.6c-0.3,0.8-0.6,1.5-0.9,2.2c-0.3,0.6,0,1,0.5,1.4 c0.5,0.4,0.9,0.9,1.1,1.4c0.9,3.1,2.6,5.7,5.1,7.8c1.3,1,2.5,2,4,2.8c1.8,0.9,3.8,1.4,5.8,1.6c2.5,0.2,5,0.3,7.4,0.6 c1.3,0.2,2.5,0.8,3.8,1.2c1,0.8,1.2,1.8,1.1,3c0,0.1-0.1,0.3-0.2,0.4C186.9,567.4,186.7,567.4,186.6,567.4L186.6,567.4z" ] []
            , Svg.path [ class "st3", d "M224.8,451l0.4,0.8c0.1,1.2,0.3,2.3,0.3,3.4c0.2,3.4,0.3,6.9,0.5,10.4c0,0.8,0.2,1.7,0.2,2.6 c0,7.7,0,15.5,0,23.2c0,2.3-0.3,4.6-0.7,6.9c-0.4,2.3-0.9,4.6-1.7,6.8c-0.8,2.2-2.1,4.4-3.3,6.4c-0.7,1.1-1.8,2-2.7,3l-0.1,0 c1.3-1.9,2.7-3.7,3.8-5.7c1.7-3.1,2.7-6.3,3.4-9.8c1.1-6.4,0.7-12.8,0.8-19.2c0-3.5,0-7,0-10.6c0-3.2-0.1-6.5-0.2-9.7 c-0.1-2.6-0.4-5.1-0.6-7.6C224.7,451.7,224.8,451.3,224.8,451L224.8,451z" ] []
            , Svg.path [ class "st4", d "M282.7,517.9c-0.1-0.2-0.3-0.4-0.4-0.6c0-1.8,0-3.6,0-5.4c0-0.2,0.3-0.4,0.3-0.6 C282.7,513.5,282.7,515.7,282.7,517.9z M283.2,501.9c0-1.8,0.1-3.6,0.2-5.4c0-0.1,0.2-0.2,0.3-0.3c0,1.5,0,3-0.1,4.4 C283.6,501.1,283.3,501.5,283.2,501.9z" ] []
            , Svg.path [ class "st3", d "M217.1,515.9c-0.6,0.5-1.2,1.1-1.8,1.6c-0.3,0.2-0.7,0.3-1,0.5l1.2-1.2c0.7-0.7,1.5-1.4,2.3-2l0.1,0 C217.5,515.1,217.3,515.5,217.1,515.9L217.1,515.9z" ] []
            , Svg.path [ class "st4", d "M284.1,487.3c0-1.4,0-2.7,0-4.1c0-0.2,0.3-0.4,0.4-0.6c0,1.3,0,2.7,0,4C284.4,486.9,284.2,487.1,284.1,487.3z" ] []
            , Svg.path [ class "st3", d "M209.7,521.1c-0.4,0.9-1.3,1.2-2.2,1.4C208.2,522,208.9,521.6,209.7,521.1z M211.9,519.7 c-0.7,0.5-1.4,1-2.2,1.4C210.4,520.6,211.1,520.2,211.9,519.7z M206.4,523.1c-0.7,0.4-1.4,0.8-2.2,1.2 C204.9,523.9,205.7,523.5,206.4,523.1z" ] []
            , Svg.path [ class "st4", d "M284,490.9c0-0.6,0-1.2,0-1.8C284,489.7,284,490.3,284,490.9z M282.9,521.1c0-0.6-0.1-1.2-0.1-1.8 C282.8,519.9,282.8,520.5,282.9,521.1z M283.5,528.1c-0.1-0.6-0.2-1.2-0.3-1.8C283.3,526.8,283.4,527.5,283.5,528.1z M284.5,481.2 c0-0.6,0-1.2,0-1.8C284.5,480,284.5,480.6,284.5,481.2z M282.8,507.3c0.1-0.6,0.2-1.1,0.3-1.7C283,506.3,282.9,506.8,282.8,507.3z M282.7,509.9c0-0.5,0-1,0-1.6C282.8,508.8,282.7,509.4,282.7,509.9z M283.6,495.5c0.1-0.6,0.2-1.1,0.3-1.6 C283.8,494.5,283.7,495,283.6,495.5z M283.6,530.7c0-0.5,0-1,0-1.6C283.6,529.7,283.6,530.2,283.6,530.7z M284.6,476.5 c0-0.5,0.1-1,0.1-1.4C284.6,475.6,284.6,476,284.6,476.5z" ] []
            , Svg.path [ class "st3", d "M203.3,524.8c-0.5,0.2-1,0.5-1.5,0.8C202.3,525.2,202.8,525,203.3,524.8z M163.4,541.5 c-0.3,0.3-0.7,0.5-1.1,0.8C162.7,542.1,163,541.8,163.4,541.5z M213.2,518.7c-0.3,0.3-0.7,0.5-1.1,0.8 C212.4,519.2,212.8,519,213.2,518.7z M170,537.8c-0.4,0.2-0.7,0.4-1.1,0.6C169.2,538.1,169.6,537.9,170,537.8z" ] []
            , Svg.path [ class "st4", d "M283.2,504.1c0-0.3,0-0.5,0-0.8C283.2,503.5,283.2,503.8,283.2,504.1z" ] []
            , Svg.path [ class "st3", d "M198.3,527.1c-0.3,0.1-0.6,0.3-0.9,0.4C197.7,527.4,198,527.2,198.3,527.1z M214,518.1 c-0.3,0.2-0.6,0.4-0.9,0.6C213.4,518.5,213.7,518.3,214,518.1z" ] []
            , Svg.path [ class "st4", d "M283.2,525.5c0-0.2,0-0.5,0-0.8C283.2,525,283.2,525.2,283.2,525.5z" ] []
            , Svg.path [ class "st3", d "M159.9,544.3l-0.7,0.6L159.9,544.3z" ] []
            , Svg.path [ class "st4", d "M284.6,474.4v-1.3V474.4z" ] []
            , Svg.path [ class "st3", d "M161.9,542.7c-0.2,0.2-0.4,0.3-0.6,0.4C161.5,543,161.7,542.9,161.9,542.7z M207.1,522.7 c-0.2,0.1-0.4,0.3-0.7,0.4C206.6,523,206.8,522.8,207.1,522.7z M164.3,540.9c-0.2,0.1-0.4,0.3-0.7,0.4 C163.9,541.2,164.1,541.1,164.3,540.9z M165,540.5c-0.2,0.1-0.4,0.3-0.7,0.4C164.5,540.8,164.7,540.7,165,540.5z M168,538.7 c-0.2,0.1-0.4,0.2-0.7,0.4C167.6,539,167.8,538.9,168,538.7z M199.2,526.7c-0.1,0.1-0.3,0.1-0.4,0.2 C198.9,526.8,199,526.8,199.2,526.7z M200.9,525.9c-0.1,0.1-0.3,0.1-0.4,0.2C200.6,526,200.8,526,200.9,525.9z M222.3,424.6 c-0.1,0-0.3,0.1-0.4,0.2C222,424.7,222.2,424.7,222.3,424.6z M160.8,543.5l-0.4,0.4C160.5,543.8,160.7,543.7,160.8,543.5z" ] []
            , Svg.path [ class "st5", d "M275.9,436h-0.4 M226,465.7c-0.2-3.4-0.3-6.9-0.5-10.4c0-1.2-0.2-2.3-0.3-3.4c1.4,0.8,2.8,1.7,4.4,2.3 c3.6,1.4,7.2,2.6,11.2,2.9c4.1,0.4,8.1,0.8,12.1,1.2c0.7,0.1,1.3,0,2,0c0.1,1,0.3,2,0.4,3c0.1,1.4,0.2,2.7,0.2,4.1 c0,1-0.1,1.9,0.1,2.8c0.1,0.4,0.6,0.9,1.1,1.2c2.3,1.3,3.1,3.5,3.8,5.7c0.8,2.6,1.2,5.2,1.1,8c0,1.3,0.2,2.6,0.2,4 c-0.1,3.6-0.2,7.2-0.4,10.9c-0.2,3-0.7,5.9-1,8.8c-0.2,2.1-0.3,4.2-0.5,6.2c-0.2,2.3-0.8,4.6-0.5,6.9c0.3,2.4-1.5,4.6,0,6.9 c-2.4,0.5-0.9,2.4-2,3.4c2.1,0.2,4,0.4,5.9,0.6c0.8,0.1,1.2,0.5,1.1,1.3c-0.1,0.8-0.2,1.5-0.2,2.3c0,1-0.4,2.1,0.7,2.9 c0.2,0.2,0.1,0.6,0.2,0.8c0,1.1,0,2.2,0,3.3c0,1,0,2.1,0.3,3.1c0.3,1.4-0.6,2.3-1.7,2.9c-3.1,2-5.8,4.6-9.4,5.9 c-3,1-20.3,8.4-22.1,8.9c-4.2,1.1-31.3,5.9-31.3,5.9c-1.1-0.4-9.4,0-11.8,0c-0.4,0-2.1-0.6-2.6-0.7c0.1-1.2-0.2-2.6-1.2-3.4 c0.7-1.2,2.8-1.8,4-2.4c2.4-1,4.8-1.9,7.2-2.8c1.4-0.5,2.8-0.9,4.3-1.3c1.8-0.5,3.6-1,5.4-1.3c3-0.6,6.1-1.1,9.1-1.7 c1.8-0.4,3.7-0.6,5.5-1.1c3.5-0.8,7-1.6,10.4-2.5c1.3-0.3,2.4-0.8,3.7-1.2c0.3-0.1,0.6-0.1,0.8-0.1c1-0.4,1.9-0.7,2.8-1.1 c0.3-0.1,0.4-0.4,0.7-0.5h0.4l0.4-0.4h0.4l0.4-0.4h0.7c2.9-1.4,5.4-3.2,7.7-5.2c2.6-2.2,4.3-5,5.8-7.8c0.4-0.8,0.9-1.7,1.1-2.6 c0.3-0.9,0.2-1.8,0.3-2.8c0.2-1.5,0.5-3.1,0.7-4.6c0.2-1,0.3-2,0.6-3.2c-0.5-0.4-0.5-1.2-0.3-2.1c0.1-0.4-0.3-0.9-0.5-1 c-1-0.4-0.5-1.4-0.4-2.1c1-0.1,1.2-0.6,0.7-1.4c-0.2-0.3-0.3-0.7-0.3-1.1c-0.1-0.7,0-1.4-0.2-2.1c-0.3-1.3-0.5-2.6-0.8-3.9 c-0.5-2.7-0.4-5.5-0.6-8.3c0-1.1,0.2-2.2-0.1-3.3c-0.7-2.4-0.9-4.8-0.6-7.2c0.1-0.8,0.3-1.8-0.1-2.4c-1-1.4-0.7-2.7-0.4-4.2 c0.2-0.7,0-1.5-0.1-2.2c-0.1-0.8-0.3-1.5-0.4-2.2c0-0.4,0-0.8,0-1.2c-0.3-1.7-0.6-3.4-0.8-5.2c-0.1-1.2-0.7-1.7-2-1.7 c-2.5,0-5.1,0-7.6,0c-1.8,0-3.6,0-5.4-0.4c-2.5-0.5-5-1.2-7.5-1.9c-1-0.3-1.8-0.7-2.7-1.1C227.3,466,226.6,465.9,226,465.7 L226,465.7z" ] []
            , Svg.path [ class "st6", d "M226,465.7c0.6,0.2,1.4,0.1,2,0.3c0.9,0.4,2,0.8,2.9,1.1c2.5,0.7,4.7,1.5,7.3,1.9c1.7,0.3,3.8,0.3,5.6,0.3 c2.5,0,5,0,7.5,0c1.3,0,1.6,1,1.8,2.1c0.2,1.7,0.6,3.4,0.8,5.2c0,0.4,0,0.8,0,1.2c0.1,0.8,0.3,1.5,0.4,2.2c0.1,0.8,0.2,1.5,0.1,2.2 c-0.3,1.4-0.7,2.8,0.4,4.2c0.4,0.6,0.2,1.6,0.1,2.4c-0.3,2.4-0.2,4.8,0.6,7.2c0.3,1,0.1,2.2,0.1,3.3c0.1,2.8,0,5.6,0.6,8.3 c0.3,1.3,0.5,2.6,0.8,3.9c0.2,0.7,0.1,1.4,0.2,2.1c0,0.4,0.1,0.8,0.3,1.1c0.5,0.8,0.3,1.2-0.7,1.4c0,0.7-0.3,1.5,0.7,1.9 c0.2,0.1,0.3,0.8,0.2,1.2c-0.2,0.8-0.4,1.4,0.1,1.8c-0.2,1.2-0.3,2.4-0.5,3.4c-0.3,1.5-0.5,3.1-0.7,4.6c-0.1,0.9-0.1,1.9-0.3,2.8 c-0.3,0.9-0.7,1.8-1.1,2.6c-1.5,2.9-3.1,5.7-5.8,7.8c-2.4,2-4.8,3.8-7.7,5.2c0.5-0.5,1-1,1.6-1.4c2.1-1.2,4-2.6,5.5-4.4 c0.2-0.2,0.3-0.5,0.3-0.7c-0.4-1.6,0-3,0.7-4.4c0.4-0.8,0.4-1.8-0.4-2.6c-0.3-0.4-0.4-1-0.4-1.5c0-0.8-0.3-1.4-1.2-1.6 c-2.1-0.5-4.2-1.1-6.3-1.7c-1.9-0.5-3.9-0.9-5.8-1.7c-3.1-1.3-6.2-2.8-9.2-4.3c-3.3-1.7-6.3-3.6-8.8-6.1c-0.3-0.2-0.8-0.6-1-0.9 c0.2-0.4,6-8.7,6.8-10.9c0.8-2.2,2.7-11.6,2.7-13.9C226.3,483.7,226.1,466.5,226,465.7L226,465.7z" ] []
            , Svg.path [ class "st3", d "M191.6,537.1c-0.1,0.6,0.2,0.8,0.8,1c3.2,1.2,6.2,2.9,8.2,5.5c1.5,1.9,2.3,4.1,1.5,6.5c-0.6,1.7-1.9,3-3.4,4.2 c-2.3,1.6-4.9,2.4-7.7,2.9c-3.2,0.6-6.4,0.7-9.5,0.5c-2.8-0.2-5.7-0.6-8.3-1.5c-2-0.6-3.8-2-5.4-3.2c-1.8-1.4-2.1-4.6-1.2-6.6 c2.1-5.2,6.8-7.8,12-9.8c3.1-1.1,6.4-1.8,9.6-2.7c0.2,0,0.4,0,0.7,0c-1.5,0.4-3.1,1-4.6,1.3c-4.4,1-8.6,2.6-12.2,5.2 c-1.4,1-2.5,2.3-3.7,3.5c-0.2,0.2-0.1,0.8-0.1,1.2c0.4,0,0.9,0,1.3,0c0.1,0,0.3-0.2,0.4-0.3c2.1-1.2,4.1-2.7,6.3-3.6 c3.4-1.2,7.1-2,10.6-2.9C188.4,537.9,190,537.5,191.6,537.1L191.6,537.1z" ] []
            , Svg.path [ class "st7", d "M191.6,537.1c-1.6,0.4-3.2,0.8-4.8,1.2c-3.6,0.9-7.2,1.7-10.6,2.9c-2.3,0.8-4.2,2.3-6.3,3.6 c-0.1,0.1-0.3,0.3-0.4,0.3c-0.4,0-0.9,0-1.3,0c0-0.4-0.1-0.9,0.1-1.2c1.2-1.2,2.3-2.5,3.7-3.5c3.6-2.6,7.8-4.2,12.2-5.2 c1.6-0.4,3.1-0.9,4.6-1.3c0.1,0,0.3,0,0.4,0c0.1,0,0.5-0.3,0.6-0.3c4.6-1,8.5-2.2,12.6-4.2c0.3-0.1,0.8-0.4,1-0.5 c0.2,0,1.4-0.8,1.6-0.8c0.3-0.5,2.1,0.3,2.3,0.6c0.2,0.4-0.1,1.3-0.5,1.7c-0.5,0.7-1.3,1.4-1.9,2c-0.7,0.6-1.4,1.1-2,1.6 c-0.1,0-0.3,0-0.3,0.1c-1.8,0.6-3.6,1.2-5.4,1.8c-1.1,0.4-2.3,0.6-3.4,1c-0.1,0-0.3,0-0.4,0c-0.3,0.1-0.5,0.2-0.7,0.3 C192.3,537.1,191.9,537.1,191.6,537.1L191.6,537.1z" ] []
            , Svg.path [ class "st3", d "M203.4,528.8c-0.3,0.2-0.5,0.4-0.7,0.5c-4.2,2-8.5,3.5-13.1,4.6c-0.1,0-0.3,0-0.4,0c0.7-0.3,1.4-0.7,2.2-0.8 c3.9-0.8,7.5-2.4,11.1-4C202.7,528.9,203.1,528.8,203.4,528.8L203.4,528.8z M202.9,533.9c0.7-0.5,1.4-1,2-1.6 c0.7-0.6,1.4-1.2,1.9-2c0.3-0.4,0.3-1.1,0-1.6c-0.1-0.3-0.9-0.4-1.4-0.4c-0.5,0-1,0.2-1.4,0.3c0.7-0.8,2.4-1.1,3.2-0.5 c0.7,0.5,0.8,1.7-0.1,2.6c-1.1,1.1-2.3,2-3.5,3C203.4,533.9,203.1,533.9,202.9,533.9L202.9,533.9z M193.8,536.7 c1.1-0.3,2.3-0.6,3.4-1c1.8-0.6,3.6-1.2,5.4-1.8c-0.7,0.4-1.3,0.9-2,1.2c-2.1,0.6-4.2,1.2-6.3,1.8 C194.1,536.9,193.9,536.8,193.8,536.7L193.8,536.7z" ] []
            , Svg.path [ class "st3", d "M192.6,537.1c0.3-0.1,0.5-0.2,0.7-0.3C193.1,536.9,192.8,536.9,192.6,537.1z" ] []
            , Svg.path [ class "st6", d "M240.2,547.9l-0.4,0.4C239.9,548.2,240.1,548.1,240.2,547.9z M241.1,547.5l-0.4,0.4 C240.8,547.8,240.9,547.7,241.1,547.5z" ] []
            , Svg.path [ class "st8", d "M179.3,571.7c4.2,0.4,8.5,1,12.7,1.2c4.1,0.2,8.3,0.2,12.5-0.2c5-0.5,10-1.5,15-2.4c6.3-1.1,12.4-3,18.4-5.2 c2.3-0.8,4.6-1.6,6.8-2.5c2.4-1,4.8-1.8,7-3c4.2-2.4,8.4-5,12.5-7.5c2.7-1.7,5.4-3.6,8.1-5.4c1.6-1,3.1-2.2,4.7-3.2 c0.3-0.2,1.1-0.3,1.5-0.4c-0.1,0.4,0,1.2-0.2,1.5c-2.9,3.5-6.7,6.3-10.5,9c-4.9,3.4-10.1,6.7-15.6,9.1c-5.9,2.7-22.4,8.4-24.4,8.9 c-1.9,0.5-9,1.9-10.5,2.2c-1.9,0.4-3.9,0.7-5.8,1c-3.2,0.4-6.4,0.9-9.6,1c-3.6,0.2-7.2,0.2-10.8,0.1c-2.8-0.1-5.7-0.4-8.4-0.7 c-3-0.4-5.8-1.5-8.6-2.5c-4-1.5-8-3.4-11.3-5.9c-3-2.2-5.2-5.1-6.6-8.4c-0.1-0.3-0.2-0.7-0.3-1.3c0.4,0.3,0.6,0.4,0.7,0.5 c1.4,2.4,3.2,4.7,5.4,6.6c3.7,3.2,8,5.3,12.8,6.6c0.2,0,0.4,0,0.7,0c0.1,0,0.5-0.1,0.6-0.1C176,570.7,178.5,571.6,179.3,571.7z" ] []
            , Svg.path [ class "st9", d "M187.2,567c0.4,0.1,0.8,0.2,1.3,0.2c2.4,0,4.8-0.1,7.2-0.2c0.4,0,0.7,0.1,1.1,0.2c-0.9,0.1-1.8,0.4-2.7,0.4 c-2.1,0-4.2,0-6.3,0c-0.3,0-0.5-0.1-0.7-0.2C187.1,567.2,187.1,567.1,187.2,567z M202,566.7c0.5-0.2,1-0.4,1.5-0.4 c1-0.1,1.9-0.1,2.9-0.2C204.9,566.3,203.5,566.5,202,566.7z M197.9,567.1c1-0.6,2.1-0.8,3.3-0.4L197.9,567.1z M206.8,566.1 c0.3,0,0.7-0.1,1.1-0.2C207.5,566,207.2,566,206.8,566.1z" ] []
            , Svg.path [ class "st5", d "M272.7,436.2l-1.3,0.4L272.7,436.2z M274.2,436.2h-0.4H274.2z" ] []
            , Svg.path [ class "st5", d "M228.4,449.5c1.7,0.4,3.4,0.8,5,1.2c0.6,0.2,1.2,0.5,1.8,0.7l-6.7-1.7C228.5,449.7,228.4,449.5,228.4,449.5 L228.4,449.5z M238,451.8c1.1,0.2,2.2,0.3,3.3,0.4C240.2,452.1,239.1,452,238,451.8z M235.6,451.4c0.6,0.1,1.2,0.2,1.8,0.4 C236.8,451.7,236.2,451.5,235.6,451.4z M248.3,453c0.5,0,1,0,1.5,0C249.3,453,248.8,453,248.3,453z M246.5,453 c-0.4-0.1-0.7-0.2-1.1-0.4" ] []
            , Svg.path [ class "st9", d "M260.9,453l0.9-0.4L260.9,453z" ] []
            , Svg.path [ class "st5", d "M241.9,452.3l0.9,0.4L241.9,452.3z M243.7,452.6c0.2,0,0.4,0,0.7,0C244.1,452.6,243.9,452.6,243.7,452.6z" ] []
            , Svg.path [ class "st9", d "M258.1,453.1h0.4C258.3,453,258.2,453,258.1,453.1z" ] []
            , Svg.path [ class "st5", d "M263.1,451.6V451V451.6z" ] []
            , Svg.path [ class "st4", d "M176.7,571.1c-0.3-0.1-0.6-0.2-0.9-0.3C176.2,570.9,176.4,571,176.7,571.1z" ] []
            , Svg.path [ class "st9", d "M283.2,501.9c0,0.4,0,0.9,0,1.3c0,0.3,0,0.5,0,0.8c0,0.6,0,1.1-0.1,1.6c-0.1,0.6-0.2,1.1-0.3,1.7v0.9 c0,0.5,0,1,0,1.6c0,0.5,0,1,0,1.4c-0.1,0.2-0.3,0.4-0.3,0.6c0,1.8,0,3.6,0,5.4c0,0.2,0.3,0.4,0.4,0.6c0,0.5,0,1,0,1.4 c0,0.6,0.1,1.2,0.1,1.8c0,0.2,0,0.4,0,0.6c0,0.4,0.1,0.9,0.1,1.4c0,0.6,0.1,1.1,0.1,1.6c0,0.2,0,0.5,0,0.8v0.8 c0.1,0.6,0.2,1.2,0.3,1.8c0,0.4,0,0.7,0,1c0,0.5,0,1,0,1.6c0,0.3,0,0.8,0.1,1.1c-0.2,0.4,0,0.6-0.3,0.9c-1.2,1.2-2.5,2.7-3.7,3.9 c-2.1,1.8-4.4,3.3-6.6,5.1c-1.7,1.4-3.5,2.8-5.4,4c-1.7,1.2-3.5,2.7-5.4,3.7c-2.8,1.5-5.8,2.5-8.7,3.8c-3.1,1.3-6.4,2.4-9.5,3.6 c-2.4,0.9-4.7,2-7.2,2.8c-4.3,1.3-8.6,2.6-13,3.6c-3.9,1-7.8,1.6-11.7,2.4c-1.3,0.2-2.6,0.3-3.8,0.4c0.2-0.1,0.3-0.3,0.5-0.4 c3.4-0.6,6.8-1.1,10.1-1.8c4.2-0.9,8.5-2,12.6-3.2c1.8-0.5,3.5-1.2,5.2-1.8c2.7-0.9,5.4-1.8,8.1-2.8c3-1.1,5.8-2.5,8.8-3.6 c3.6-1.2,6.9-2.8,10-4.9c1-0.7,2-1.5,1.7-2.9c-0.2-1-0.2-2-0.3-3.1c0-1.1,0-2.2,0-3.3c0-0.3,0-0.7-0.2-0.8c-1-0.8-0.7-1.9-0.7-2.9 c0-0.8,0.1-1.5,0.2-2.3c0.1-0.8-0.3-1.2-1.1-1.3c-1.9-0.2-3.8-0.4-5.9-0.6c1-0.9-0.4-2.8,2-3.4c-1.5-2.3,0.3-4.6,0-6.9 c-0.3-2.3,0.3-4.6,0.5-6.9c0.2-2.1,0.3-4.2,0.5-6.2c0.3-3,0.8-5.9,1-8.8c0.3-3.6,0.3-7.2,0.4-10.9c0-1.3-0.2-2.6-0.2-4 c0.1-2.7-0.3-5.4-1.1-8c-0.7-2.2-1.5-4.4-3.8-5.7c-0.5-0.3-1-0.7-1.1-1.2c-0.2-0.9-0.1-1.9-0.1-2.8c0-1.4-0.1-2.7-0.2-4.1 c-0.1-1-0.3-2-0.4-3c6.2,0,12.3,0.2,18.4-1.2c1.7-0.4,3.4-0.8,5.1-1.3c1.6-0.5,3.2-1,4.8-1.5c1.2,5.7,1.3,11.5,1.4,17.2 c0,0.6,0.1,1.1,0.1,1.7v1.3c0,0.2,0,0.4,0,0.7c0,0.5-0.1,1-0.1,1.4c0,1,0,2,0,3c0,0.6,0,1.2,0,1.8c0,0.5,0,1,0,1.4 c-0.1,0.2-0.4,0.4-0.4,0.6c0,1.4,0,2.7,0,4.1v1.7c0,0.6,0,1.2,0,1.8c0,1,0,2-0.1,3c-0.1,0.6-0.2,1.1-0.3,1.6v0.7 c-0.1,0.1-0.3,0.2-0.3,0.3C283.3,498.3,283.3,500.1,283.2,501.9L283.2,501.9z" ] []
            , Svg.path [ class "st0", d "M170,537.8c3.1-1.2,6.2-2.5,9.3-3.6c3.1-1.1,6.2-2.1,9.2-3.2c3-1.1,6-2.3,8.9-3.4c0.3-0.1,0.6-0.3,0.9-0.4 c0.1-0.1,0.3-0.1,0.4-0.2s0.3-0.1,0.4-0.2l1.3-0.6c0.1-0.1,0.3-0.1,0.4-0.2c0.3-0.1,0.6-0.3,0.9-0.4c0.5-0.2,1-0.5,1.5-0.8 c0.3-0.2,0.6-0.3,0.8-0.4c0.7-0.4,1.4-0.8,2.2-1.2c0.2-0.1,0.4-0.3,0.7-0.4c0.1-0.1,0.3-0.2,0.4-0.2c0.9-0.2,1.8-0.5,2.2-1.4 c0.7-0.5,1.4-1,2.2-1.4l0.2-0.2c0.3-0.3,0.7-0.5,1.1-0.8c0.3-0.2,0.6-0.4,0.9-0.6l0.2-0.2c0.3-0.2,0.7-0.2,1-0.5 c0.7-0.5,1.2-1,1.8-1.6c0.2,0.3,0.4,0.6,0.7,0.9c2.5,2.6,5.4,4.7,8.7,6.4c3,1.5,6.1,3,9.2,4.3c1.8,0.8,3.8,1.1,5.8,1.7 c2.1,0.6,4.2,1.2,6.3,1.7c1,0.2,1.7,0.4,1.7,1.2c0,0.5,0.1,1.5,0.5,1.9c0.9,0.8,0.9,1.8,0.5,2.7c-0.7,1.4-0.6,5-2.2,6.6 c0,0.2-6,3.9-6.5,4.4h-0.7l-0.4,0.4h-0.4l-0.4,0.4c0,0-2.3,1-3.3,1.4c-0.2,0.1-0.5,0-0.7,0.2c-0.3,0-0.6,0-0.8,0.1 c-1.2,0.4-2.4,0.8-3.7,1.2c-3.4,0.8-6.9,1.7-10.4,2.5c-1.8,0.4-3.7,0.7-5.5,1.1c-3.1,0.6-6.1,1.1-9.1,1.7c-1.8,0.4-3.6,0.8-5.4,1.3 c-1.4,0.4-2.9,0.8-4.3,1.3c-2.4,0.9-4.9,1.8-7.2,2.8c-1.2,0.5-2.6,0.9-3.2,2.2c-1.3-0.4-2.5-1-3.8-1.2c-2.4-0.3-5-0.4-7.4-0.6 c-2.1-0.2-4.1-0.7-5.8-1.6c-1.4-0.7-2.7-1.8-4-2.8c-2.6-2.1-4.3-4.7-5.1-7.8c-0.1-0.5-0.6-1.1-1.1-1.4c-0.6-0.4-0.8-0.8-0.5-1.4 c0.3-0.7,0.6-1.5,0.9-2.2l0.7-0.6l0.4-0.4l0.4-0.4l0.4-0.4c0.2-0.2,0.4-0.3,0.6-0.4c0.1-0.1,0.3-0.2,0.4-0.4 c0.3-0.3,0.7-0.5,1.1-0.8l0.2-0.2c0.2-0.1,0.4-0.3,0.7-0.4s0.4-0.3,0.7-0.4c0.8-0.5,1.6-0.9,2.4-1.4c0.2-0.1,0.4-0.2,0.7-0.4 c0.3-0.1,0.6-0.3,0.9-0.4C169.2,538.1,169.6,537.9,170,537.8L170,537.8z M189.1,533.9c-0.1,0-0.2,0.1-0.4,0.1 c-0.2,0-0.5,0.1-0.7,0.1c-3.2,0.9-6.4,1.5-9.5,2.7c-5.2,1.9-9.7,4.3-11.8,9.5c-0.8,2-0.6,5,1.2,6.5c1.6,1.3,3.1,2.7,5.1,3.3 c2.7,0.8,5.5,1.3,8.3,1.5c3.1,0.2,6.3,0.1,9.5-0.5c2.8-0.5,5.5-1.2,7.7-2.9c1.5-1.1,2.8-2.4,3.4-4.2c0.8-2.4,0-4.6-1.5-6.5 c-2.1-2.6-5-4.3-8.2-5.5c-0.5-0.2-0.9-0.4-0.8-1c0.3,0,0.7,0,1-0.1c0.3-0.1,0.5-0.2,0.7-0.3c0.1,0,0.3,0,0.4,0 c0.2,0,0.3,0.2,0.5,0.2c2.1-0.6,4.2-1.1,6.3-1.8c0.7-0.2,1.4-0.8,2-1.2c0.1,0,0.3,0,0.3-0.1c0.3,0,0.6,0,0.7-0.1 c1.2-1,2.4-1.9,3.5-3c0.9-0.8,0.8-2,0.1-2.6c-0.8-0.6-2.4-0.3-3.2,0.5c-0.2,0-0.4,0.1-0.6,0.1c-0.3,0.1-0.7,0.1-1,0.3 c-3.6,1.6-7.2,3.2-11.1,4c-0.7,0.2-1.3,0.6-2,0.9H189.1z" ] []
            , Svg.path [ class "st4", d "M208.4,565.9c1.3-0.1,2.6-0.2,3.8-0.4c3.9-0.8,7.9-1.4,11.7-2.4c4.4-1.1,8.7-2.3,13-3.6 c2.4-0.8,4.8-1.9,7.2-2.8c3.2-1.2,6.4-2.2,9.5-3.6c3-1.2,5.8-2.7,8.6-4.1c1.9-1,15-11,17.1-12.9c1.3-1.2,2.4-2.4,3.7-3.6 c0.3-0.3,0.5-0.7,0.7-1c0.1,0.2,0.3,0.4,0.3,0.6c0.1,4.3,0,8.7-1.9,12.7c-1.8,3.8-4.5,6.9-8.4,9.1c-2.9,1.7-5.8,3.4-8.8,4.9 c-3.1,1.6-6.4,3.2-9.6,4.7c-3.8,1.8-7.7,3.8-11.6,5.5c-5.2,2.2-10.4,4.4-15.7,6.1c-5.2,1.7-10.7,3-16.1,4.1 c-4,0.8-8.1,1.1-12.2,1.5c-2.9,0.2-5.8,0.3-8.7,0.2c-4.3-0.1-8.5-0.8-12.7-1.6c-0.3-0.1-0.7-0.2-1-0.4c0.1-1.4,0-2.8,0.3-4.2 c0.1-0.7,0-0.8-0.7-1.1c-3.5-1.5-7.1-2.8-10.5-4.5c-3.9-2-7.1-4.7-9.3-8.3c-0.7-1.1-1.1-2.4-1.6-3.7c-0.1-0.2,0.2-0.6,0.3-0.9 c0.3,0.1,0.7,0.2,1,0.4c0.1,0,0.7,0.4,0.4,0.4c2,3.1,4.3,5.7,7.4,8c2.7,2,5.6,3.4,8.9,4.4c0.7,0.2,1.7,0.9,2.4,1.3 c-0.2,0-1,0.1-1.2,0c-4.8-1.3-9.2-3.4-12.8-6.6c-2.2-1.9-3.9-4.2-5.4-6.6c-0.1-0.1-0.3-0.2-0.7-0.5c0.1,0.6,0.2,1,0.3,1.3 c1.4,3.4,3.8,6,6.8,8.2c3.4,2.5,7.2,4.2,11.2,5.8c2.8,1,5.5,2.1,8.5,2.5c2.8,0.3,5.6,0.7,8.4,0.8c3.6,0.1,7.2,0.1,10.7-0.1 c3.3-0.2,6.5-0.7,9.7-1.1c1.9-0.2,3.8-0.6,5.8-0.9c1.5-0.3,3.1-0.7,4.6-1c2-0.4,4-0.7,5.9-1.2c2.1-0.6,4.1-1.4,6.1-1.9 c6.3-1.8,12.4-4.3,18.3-7c5.5-2.5,10.7-5.4,15.6-8.8c3.8-2.6,7.2-5.6,10.2-9c0.2-0.3,0.2-0.7,0.3-1.1c-0.4,0-0.8,0-1.1,0.2 c-1.6,1-3.1,2.2-4.7,3.2c-2.7,1.8-5.3,3.6-8.1,5.4c-4.1,2.6-8.2,5.1-12.5,7.5c-2.2,1.2-4.7,2.1-7,3c-2.3,0.9-4.5,1.7-6.8,2.5 c-6,2.1-12.1,4-18.4,5.2c-5,0.9-9.9,1.8-15,2.4c-4.1,0.4-8.3,0.4-12.5,0.2c-4.2-0.2-8.1-0.7-12.3-1.2c-1.4-0.1-2.2-0.6-2.8-0.6 c0.9-0.3,2-0.3,2.1-1.4c0.1-0.9,0.8-1,1.6-1c1.2,0,2.5,0,3.7-0.2c0.8-0.1,2,0,2-1.4l0.6,0.1c0.3,0.1,0.3,0.2,0.6,0.2 c2.1,0,4.2,0,6.3,0c0.9,0,1.8-0.2,2.7-0.4c0.3,0,0.7,0,1.1,0l3.3-0.4h0.9c1.4-0.2,2.9-0.4,4.4-0.6c0.1,0,0.3,0,0.4,0 c0.3,0,0.7-0.1,1.1-0.2C208.1,565.9,208.2,565.9,208.4,565.9L208.4,565.9z" ] []
        ], g []
            [ Svg.path [ id "bg_1_", class "st0", d "M316.5,467.2c0,0,0.3,69.8-5.9,78.7c-6.2,8.9-27.8,31.5-24.4,41.9c3.4,10.4,3.9,17.4,19.4,19.8 c15.5,2.4,49.9,2.9,57.8-4.7c8-7.5,13.5-5.3,14-21.9c0.5-16.6-3.1-51.8,1.4-64.7s14.5-46.3,14.5-46.3s-15.2,12.5-43,6.6 C322.6,470.7,316.5,467.2,316.5,467.2z" ] []
            , Svg.path [ class "st5", d "M312,533.9l0-0.3c0.1-0.1,0.3-0.2,0.3-0.3c0.1-0.8,0.2-1.6,0.3-2.3c0.2-1.3,0.7-2.6,0.9-4 c0.8-7.5,1.7-15,2.4-22.5c0.2-2.1,0.3-4.2,0.3-6.3c0.1-4.3,0.3-8.6,0.3-12.9c0-0.8,0.4-1.8-0.8-2.5c0.2-2.4,0.4-4.7,0.6-7.1 c0-0.7,0-1.4,0.1-2.1c0.2,0.1,0.3,0.2,0.5,0.2c3.1,3.2,7.1,5.5,11.4,7.4c2.3,1,4.7,1.8,7.2,2.5c4.2,1.3,8.5,1.9,12.8,2.5 c2,0.2,4,0.5,6,0.9c1.5,0.4,3,0.9,4.3,1.6c1.5,0.8,2.8,1.9,3.5,3.3c0.4,0.7,1.1,1.4,1.2,2.2c0.7,2.8,1.1,5.7,0.7,8.6 c0,0-2.1,9.3-2.2,10.8c-0.1,1.9-0.9,3.6-1.7,5.3c-0.1,0.3-2.3,2.8-2.8,3.3c-1,1.2-1.5,7.2-1.6,7.4c-0.6,1-13.5,20.5-13.8,21.4 c-0.2,0.6-0.4,1.3-0.9,1.5c-1.1,0.5-1.5,1.3-1.8,2.2c-0.1,0.2-0.2,0.6-0.4,0.7c-0.9,0.3-1.1,1-1.2,1.7c-0.2,0.8-0.3,1.6-0.5,2.3 c-0.3,0.7-0.7,1.4-1,2c-0.4,0.7,0.1,1.1,0.9,1.2c0.4,0.1,0.8,0.2,1.2,0.3c-0.4,0-0.9,0.1-1.3,0c-1.3-0.2-2.6-0.4-3.8-0.6 c-0.5-0.1-1.1-0.1-1.6-0.3c-2.1-0.6-4.2-1.2-6.3-1.8c-0.8-0.2-1.6-0.4-2.4-0.7l-0.4-0.1c-0.8-0.3-1.6-0.7-2.4-1l-0.4-0.1 c-0.6-0.3-1.2-0.6-1.7-0.9l-0.4-0.1c-0.2-0.1-0.4,0.2-0.6,0c0,0-0.7-0.9-1-1.1l-0.4-0.1l-0.6-0.6c-1.5-1-3-2-4.4-3.1 c-1.1-0.8-2.1-1.7-3.1-2.6c0.1-0.4,0.2-0.8,0.4-1.2c0.9-2.2,1.9-4.4,2.7-6.7c0.6-1.7,1-3.4,1.4-5.1C311.9,536,311.9,535,312,533.9 L312,533.9z" ] []
            , Svg.path [ class "st1", d "M364.1,502.7c0.5-2.9,0-5.7-0.7-8.6c-0.2-0.8-0.9-1.4-1.2-2.2c-0.7-1.4-2-2.5-3.5-3.3 c-1.3-0.7-2.8-1.3-4.3-1.6c-1.9-0.4-4-0.6-6-0.9c-4.3-0.5-8.7-1.2-12.8-2.5c-2.5-0.8-4.9-1.5-7.2-2.5c-4.3-1.9-8.3-4.2-11.4-7.4 c-0.1-0.1-0.3-0.2-0.5-0.2c-0.1-2.9-0.1-5.8-0.2-8.7c0.1,0.1,0.3,0.1,0.4,0.2c1.6,1.1,3.3,2.2,5,3.2c2.8,1.7,5.9,2.7,9,3.5 c2.8,0.7,5.6,1.4,8.3,1.9c2.8,0.6,5.6,1.3,8.4,1.7c4.6,0.6,9.1,1,13.7,1.2c3.3,0.2,6.6,0.1,9.9-0.1c2.8-0.2,5.5-0.5,8.3-0.9 c2.6-0.4,5.2-0.9,7.9-1.3c1.9-0.3,3.9-0.5,5.8-0.8c-0.3,1.7-0.7,3.4-1,5.1c-0.3,1.4-0.6,2.8-0.9,4.2c-0.4,1.8-0.9,3.5-1.3,5.3 c-0.2,0.9-0.4,1.8-0.7,2.7c-0.4,1.2-0.9,2.4-1.1,3.6c-0.4,1.8-0.7,3.6-1.1,5.4c-0.7,3.2-1.6,6.4-2.2,9.7c-0.8,3.7-1.4,7.4-2,11.1 c-0.5,2.8-0.8,5.6-1.2,8.5c-0.3,2.2-0.6,4.3-1,6.5c-0.6,4-1.3,8-1.9,12c-0.5,3.4-0.7,6.9-1,10.3l-3.3,1.7c-1.4,0.5-2.9,1.3-4.4,1.6 c-2.6,0.7-5.7,1.2-8.4,1.8c-1.6,0.3-3.5,0.9-5.1,1.1c-1.2,0.1-0.8-1-0.6-2.1c0.2-1.6,0.5-3.2,0.8-4.8c0.5-2.7,1-5.5,1.4-8.2 c0.7-4,1.4-8,1.9-12.1c1.2-9.4,2.3-18.8,3.4-28.2c0.2-1.2,0.4-2.4,0.7-3.6C363.9,504.3,364,503.5,364.1,502.7L364.1,502.7z" ] []
            , Svg.path [ class "st4", d "M332.8,620.1c0.2-1.2,0.4-2.4,0.6-3.6c0.1-0.5,0.1-0.9-0.5-1.2c0.3-0.1,0.6-0.2,0.9-0.3c0.5-0.1,1,0,1.5,0 c2.7-0.4,5.4-0.7,8-1.2c3.5-0.6,6.7-1.8,9.8-3.2c2.4-1.1,4.6-2.4,7-3.7c4-2.1,7.6-4.5,10.3-7.7c0.8-1,1.5-2.2,2.2-3.3 c0.1-0.2-0.1-0.6-0.2-0.9c-0.3,0.1-0.8,0.2-1,0.4c-0.4,0.4-0.8,0.9-1.1,1.4c-2.1,3-5.3,5.3-8.6,7.4c-2.3,1.4-5,2.6-7.6,3.7 c-2.4,1-5,1.8-7.6,2.7c-1,0.4-2.2,0.4-3.3,0.7c-3,1-6.2,1.2-9.3,1.6c1.7-1.2,1.5-3.2,2.5-4.7c-0.6-0.1-1.2-0.2-1.7-0.3 c0.8-0.1,1.5-0.2,2.3-0.3c1.3-0.1,2.6-0.1,3.9-0.4c2.6-0.6,5.2-1.2,7.7-1.9c2.5-0.8,5-1.7,7.4-2.7c3.5-1.6,6.7-3.4,9.5-5.7 c1.1-0.8,2.3-1.6,3.1-2.6c1.1-1.4,2.8-2.4,3.5-4.1c0.6-1.5,1.9-2.8,2.4-4.2c1.5-3.9,2.6-7.8,3.9-11.8c0.3-0.9,0.6-1.7,0.5-2.6 c-0.2-2.3-0.7-4.6-0.9-7c-0.2-1.9-0.2-3.8-0.2-5.7c0-0.3-0.1-0.6-0.1-0.9c0.3-3.5,0.6-6.9,1-10.3c0.5-4,1.2-8,1.9-12 c0.3-2.2,0.6-4.3,1-6.5c0.4-2.8,0.8-5.7,1.2-8.5c0.6-3.7,1.2-7.4,2-11.1c0.7-3.2,1.5-6.5,2.2-9.7c0.4-1.8,0.7-3.6,1.1-5.4 c0.3-1.2,0.8-2.4,1.1-3.6c0.3-0.9,0.5-1.8,0.7-2.7c0.4-1.8,0.9-3.5,1.3-5.3c0.3-1.4,0.6-2.8,0.9-4.2c0.4-1.7,0.7-3.4,1-5.1 c0.1-1.2,0.1-2.3,0.2-3.5c0.4-0.4,0.6-0.1,0.6,0.3c-0.2,1.4-0.3,2.9-0.6,4.4c-0.4,2.2-0.9,4.4-1.5,6.6l-1.4,6 c-1,3.9-2.1,7.8-3,11.7c-0.6,2.7-1,5.4-1.7,8c-1.3,4.9-2,9.8-2.6,14.7c-0.5,3.5-1.1,7-1.6,10.5c-0.8,5.2-1.5,10.4-2.3,15.5 c-0.3,1.8-0.7,3.7-0.8,5.6c-0.2,3.2-0.6,6.4-0.1,9.7c0.4,2.7,0.8,5.4,1,8.1c0.2,1.9,0.2,3.9,0.1,5.8c-0.1,2.5-0.3,5.1-0.7,7.5 c-0.7,4.1,0,6.8-3.3,13.9c-1.6,2.3-2.6,3.7-4.4,5.9c-3.8,3.8-4.9,5.3-7.8,7.2c-3.6,2.4-6.9,4.6-11.5,6.2c-4.3,1.5-8.9,2.1-13.5,2.4 C336.6,620.2,334.7,620.1,332.8,620.1L332.8,620.1z" ] []
            , Svg.path [ class "st10", d "M305.5,559.4c0,0,3-2.5,2.4,0.1c-0.6,2.7-3.9,6-7.6,10.5c-3.6,4.5-5.5,4.6-5.8,12.7c-0.3,8.8-0.3,8.8-0.3,8.8 s-3.2-1.8-2.6-10.5c0.7-8.7,6.6-13.6,7.6-14.5C300.4,565.6,305.5,559.4,305.5,559.4z" ] []
            , Svg.path [ class "st8", d "M393.3,470c-0.1,1.2-0.1,2.3-0.2,3.5c-1.9,0.3-3.9,0.5-5.8,0.8c-2.6,0.4-5.2,0.9-7.9,1.3 c-2.8,0.4-5.5,0.7-8.3,0.9c-3.3,0.2-6.6,0.3-9.9,0.1c-4.6-0.2-9.2-0.7-13.7-1.2c-2.8-0.3-5.6-1.1-8.4-1.7c-2.8-0.6-5.6-0.7-8.4-1.5 c-3.2-0.9-6.2-2.3-9-4c-1.7-1-3.3-2.1-5-3.2c-0.1-0.1-0.3-0.1-0.4-0.2c-0.1-0.7,0.1-2.1,0-2.8c0-0.6,0.3-1.4,0.3-2 c0.3,0.1,1.3,0.5,1.5,0.6c1.9,0.8,2.6,1.5,4.5,2.3c3.8,1.5,7.4,3.7,11.3,5.1c1.2,0.4,2.5,0.6,3.8,0.9c0.1,0,0.3,0,0.5,0l0,0 c0.1,0.1,0.2,0.3,0.4,0.4c0.9,0.2,1.9,0.4,2.8,0.5c0.7,0.1,1.4,0.1,2.1,0.1c0.5,0.1,1,0.1,1.6,0.2c0.3,0.1,0.5,0.4,0.8,0.4 c2,0.3,4.1,0.7,6.2,0.9c3.2,0.4,6.4,0.8,9.7,1.1c1.8,0.2,3.6,0.2,5.3,0.1c4.8-0.1,9.5-0.4,14.3-0.6c2.8-0.1,5.6-0.4,8.2-1.3 C390.9,470.4,392.1,470.2,393.3,470L393.3,470z" ] []
            , Svg.path [ class "st9", d "M377.6,557.9c0.1,0.3,0.1,0.6,0.1,0.9c0.1,1.9,0.1,3.8,0.2,5.7c0.2,2.3,0.7,4.6,0.9,7c0.1,0.9-0.2,1.7-0.5,2.6 c-1.2,3.9-2.5,7.9-3.9,11.8c-0.5,1.5-1.8,2.8-2.4,4.2c-0.7,1.7-2.4,2.7-3.5,4.1c-0.8,1-2,1.8-3.1,2.6c-2.8,2.2-6.1,4.1-9.5,5.7 c-2.3,1.1-4.8,1.9-7.4,2.7c-2.5,0.8-5.1,1.4-7.7,1.9c-1.2,0.3-2.6,0.3-3.9,0.4c0.5-1.1,0.9-2.2,1.6-3.2c1.2-1.9,2.6-3.7,3.9-5.6 c1.6-2.4,3.2-4.7,4.7-7.1c1.2-1.8,2.2-3.6,3.1-5.6c0.7-1.5,1.2-3,1.6-4.5c0.7-2.4,1.6-4.8,2-7.3c0.6-3.2,0.9-6.4,1.4-9.7 c0.1-1.1-0.3-1.5-1.8-1.3c-3,0.3-6,0.5-9,0c-0.2,0.1-0.5,0.2-0.7,0.3l-5.6-0.7c-0.4-0.1-0.8-0.2-1.2-0.3c-0.9-0.1-2.5-0.1-2.1-0.9 c-1.2,0.3,1.7-3.8,1.9-4.5c0.2-0.7,1.1-5.8,4-6.5c0.3-0.9,1.5-1.5,1.7-2.3c0-0.1,0-0.3,0.1-0.4c1.2-0.8,1.3-2.1,2-3.1 c0.1-0.1,0.3-0.3,0.4-0.4c1.3-0.2,1.5-1.1,1.6-2c0.1-1.4,0.5-2.6,1.6-3.8c0.4-0.4,0.4-1.2,0.7-1.7c0.2-0.4,0.8-0.6,1.2-0.9 c0.4-0.3,0.9-0.6,1-1c0.3-1.1,0.5-2.3,0.7-3.4c0-0.1,0-0.4,0.1-0.4c1.2-0.7,1.2-1.9,1.8-2.9c0.2-0.2,0.4-0.5,0.6-0.6 c1.3-0.2,1.4-1.1,1.4-1.9c0.1-1.4,2.2-5.2,2.3-5.9c0.1-0.5,0.4-0.6,1-0.7c0.4,0,1.9-3.6,2-5.5c0.1-1.5,1.1-4.6,1.4-6.1 c0-0.2,1.6-6.3,1.8-6.4c-1.1,9.4-3.2,26.1-4.4,35.5c-0.5,4-1.2,8-1.9,12.1c-0.5,2.7-1,5.5-1.4,8.2c-0.3,1.6-0.6,3.2-0.8,4.8 c-0.2,1,0,1.2,1.3,1.1c1.7-0.2,3.3-0.4,4.8-0.7c2.6-0.5,5.3-1.1,7.9-1.8c1.5-0.4,2.9-1,4.3-1.5 C375.3,558.7,376.4,558.3,377.6,557.9L377.6,557.9z M364.1,502.7L364.1,502.7z M393.3,470c-1.2,0.3-2.5,0.4-3.6,0.8 c-2.6,0.9-5.4,1.2-8.2,1.3c-4.7,0.3-9.5,0.5-14.3,0.6c-1.8,0-3.6,0-5.3-0.1c-3.2-0.3-6.4-0.7-9.7-1.1c-2.1-0.3-4.1-0.6-6.2-0.9 c-0.3,0-0.5-0.3-0.8-0.4c0.3,0,0.6,0,0.9,0.1c2.2,0.3,4.4,0.7,6.6,1c4.8,0.6,9.6,1.3,14.4,1.1C368.1,472.2,393.7,469.5,393.3,470 L393.3,470z" ] []
            , Svg.path [ class "st9", d "M343.7,469.9c-0.7,0-1.4,0-2.1-0.1c-0.9-0.1-1.9-0.3-2.8-0.5c-0.2,0-0.3-0.3-0.4-0.4c0.8,0.1,1.7,0.2,2.5,0.3 c0.1,0.1,0.3,0.1,0.4,0.2C342,469.6,342.8,469.8,343.7,469.9L343.7,469.9z" ] []
            , Svg.path [ class "st5", d "M370,471.9" ] []
            , Svg.path [ class "st3", d "M312.5,599.1c-2.8-0.6-5.8-1.2-8.5-2c-4.1-1.3-7.8-3.1-10.4-6.3c-1.2-1.5-1.7-2.8-1.8-4.4 c-0.2-3.3,0.1-6.6,1.2-9.8c1-2.9,3-5.4,4.9-7.9c2.2-2.8,4.6-5.5,7-8.3c0.3-0.3,0.4-0.6,0.7-0.9c0.7-0.8,1.7-1.1,2.6-0.7 c1,0.4,1.2,1.1,0.9,2.1c-0.8,2.4-2.4,4.5-4.3,6.5c-2.1,2.4-4.2,4.8-6.3,7.2c-0.3,0.3,0,0.6-0.1,0.9c0.4,0,0.5,0.1,1,0.1 c3.6-0.1,7,0.8,10.2,2.1c1.8,0.7,8-9.6,9.9-8.9c0.3,0.2-0.3,9.3,0.1,9.6c2.9,1.7,3.4,4.9,5.9,7.1c2.4,2,4.8,5,6.3,7.5 c0.9,1.5-0.1,3-1.4,4.5c-0.8,1-2.2,1.7-3.8,1.8c-2.4,0.2-4.8,0.3-7.3,0.2C317,599.4,312.5,599.1,312.5,599.1z M315.9,482.2 c1.2,0.7,1.1,2.2,1.1,3.1c-0.1,4.3-0.4,17.3-0.6,19.4c-0.7,7.5-3.6,28.2-3.7,28.9c0,0.1-0.7-0.1-0.8,0c0.1-1.6,0.3-3.3,0.5-5 c0.1-0.4,0.2-0.8,0.3-1.3c0.7-6.1,1.5-12.2,2.1-18.2c0.4-3.6,0.6-7.3,0.8-10.9c0.2-3.1,0.2-6.2,0.2-9.4c0-2-0.1-4.1-0.1-6.2 L315.9,482.2z M312.5,533.9c-0.1,1-0.7,2.1-0.9,3c-0.4,1.7-0.8,3.4-1.4,5.1c-0.8,2.3-1.8,4.5-2.7,6.7c-0.2,0.4,0,1.7-0.1,2 c-0.8,1.2-2.1,2.9-3,4c-2,2.5-4.3,4.8-6.4,7.2c-0.6,0.6-1.3,1.4-1.9,1.9l-0.9,0.1c0.6-0.8,1.9-2.3,2.6-3c1.6-1.8,3.4-3.6,4.9-5.5 c1.1-1.4,1.9-3,2.8-4.5c2.3-3.7,3.8-7.6,4.8-11.7l1.3-4.9c0.1-0.1,0.3-0.2,0.4-0.4H312.5z" ] []
            , Svg.path [ class "st9", d "M337.9,468.9c-1.3-0.3-2.6-0.4-3.8-0.9c-3.9-1.4-7.7-2.9-11.5-4.3c-2-0.7-4.2-1.8-6.1-2.6c0,0.4,0.2,0.5,0,0.4 c0,0.6,0.3-1.6,0.3-1.6s7.6,3.9,11,5.3c1.8,0.7,3.5,1.5,5.3,2.1c1.6,0.5,3.3,0.8,4.9,1.2C337.9,468.6,337.9,468.8,337.9,468.9 L337.9,468.9z" ] []
            , Svg.path [ class "st6", d "M339.3,563l4.7,0.6c0.2-0.1,0.5-0.2,0.7-0.3c3,0.5,6,0.3,9,0c1.4-0.2,1.9,0.2,1.8,1.3 c-0.4,3.2-0.8,6.5-1.4,9.7c-0.5,2.5-1.3,4.9-2,7.3c-0.5,1.5-0.9,3.1-1.6,4.5c-0.9,1.9-2,3.7-3.1,5.6c-1.5,2.4-3.1,4.7-4.7,7.1 c-1.3,1.9-2.7,3.7-3.9,5.6c-0.7,1-1.1,2.1-1.6,3.2c-0.8,0.1-1.5,0.2-2.3,0.3l-0.7-0.1c-0.9,0-1.8,0-2.7,0c-0.3,0-0.6-0.1-0.9-0.1 c-0.8,0-1.5,0-2.3,0.1l-3.2-0.3c-1-0.2-2.1-0.1-3.1-0.3c-0.5-1.7-1.7-2.7-3.8-3.1c-2.5-0.4-5.1-1.1-7.6-1.6 c0.1-0.5,0.1-1.1,0.3-1.6c-0.2-0.5,0-0.8,0.5-0.8c0.9-0.1,1.2-0.6,1.3-1.2c2.3,0.2,4.5,0.5,6.8,0.6c2.4,0.1,4.9-0.1,7.3-0.2 c1.5-0.1,2.9-0.8,3.8-1.8c1.2-1.5,0.9-3.1,0-4.7c-1.4-2.5-3.5-4.7-6-6.6c-2.6-2.1-5.4-3.8-8.4-5.6c-0.3-0.2-0.7-0.5-1.1-0.7 c-0.1-0.9-0.2-1.9-0.3-2.8c0-0.2,0.1-0.3,0.2-0.4c0.2-0.5,0.4-1.1,0.7-1.6c0.4-0.8,0.7-1.5,1.1-2.3c0.1-0.2,0.4-0.4,0.5-0.7 c0.9-1.4,1.5-2.9,2.3-4.4c0.6-1,0.9-2.2,1.6-3.3c0.7-0.9,1.6-1.4,2.8-1.7c0.3-0.1,0.7-0.2,1-0.3c0-0.1,0-0.2,0-0.4 c-0.7-0.1-1.4-0.2-2.4-0.4c0.8-0.2,1.3-0.4,1.7-0.5c-0.5-0.6-1.6-1.4-2.1-1.9c0.8,0.2,2.3,0.7,3.1,0.9c2.1,0.6,4.2,1.2,6.3,1.8 c0.5,0.1,1.1,0.2,1.6,0.3c1.3,0.2,2.6,0.5,3.8,0.6c0.4,0,0.9,0,1.3,0l0.4,0.1C339,563,339.1,563,339.3,563L339.3,563z" ] []
            , Svg.path [ class "st0", d "M312.6,598.9c-0.1,0.6-0.4,1.1-1.3,1.2c-0.5,0-0.7,0.3-0.5,0.8c0.2,0.4-0.4,1.5-0.4,2 c-5.5-1.1-10.8-2.9-15.9-5.3c-2.7-1.2-4.7-2.8-5.9-5c-0.3-0.6-0.5-1.3-1-1.9c-0.7-1-1.8-0.9-2.9-0.8c-1,0.1-1.9-0.5-1.8-1.3 c0-0.2,0.1-0.5-0.1-0.7c-0.8-0.9-0.4-1.8-0.3-2.7c0.1-2,0.3-4,0.9-5.9c0.5-1.6,1.4-3.2,2.5-4.5c2.6-3.1,5.5-6.1,8.2-9.2 c0.6-0.7,1.2-1.4,1.7-2.1c0.7-0.5,1.4-1.1,2-1.7c2.1-2.4,4.3-4.8,6.3-7.3c0.9-1.1,1.5-2.4,2.3-3.6c0.2-0.3,0.5-0.5,0.7-0.8 c1,0.9,2,1.8,3.1,2.6c1.5,1.1,3,2.1,4.4,3.1l1.1,0.7c0.3,0.2,0.5,0.4,0.8,0.7l0.2,0c0.2,0.1,1.1,0.5,1.1,0.5c0.6,0.3,2.2,1,2.2,1 c0.8,0.3,2.8,1.1,2.8,1.1c0.7,0.3,2.8,2.5,2.5,3.3c-0.3,0.1-1-0.2-1.4-0.1c-1.2,0.3-1.9,1-2.5,1.9c-0.7,1.1-1,2.2-1.6,3.2 c-0.8,1.5-1.7,2.8-2.6,4.2c-0.2,0.2-0.4,0.4-0.5,0.7c-0.4,0.8-0.8,1.5-1.1,2.3c-0.2,0.5-0.4,1.1-0.7,1.6c-0.1,0.1-0.2,0.3-0.2,0.4 c0.1,0.9,0.2,1.9,0.3,2.8c-1.8-0.7-3.6-1.5-5.5-2.2c-3.2-1.3-6.6-2.1-10.2-2c-0.4,0-0.8-0.1-1.2-0.1c0.1-0.4,0.1-0.8,0.3-1.1 c2.1-2.4,4.1-4.8,6.3-7.2c1.8-2,3.4-4,4.3-6.5c0.3-1,0.1-1.7-0.9-2.1c-0.9-0.4-1.9-0.1-2.6,0.7c-0.3,0.3-0.4,0.6-0.7,0.9 c-2.3,2.7-4.7,5.5-7,8.3c-1.9,2.5-3.9,5-4.9,7.9c-1.1,3.2-1.4,6.4-1.2,9.8c0.1,1.6,0.6,3,1.8,4.4c2.6,3.2,6.3,5.1,10.4,6.3 C306.9,598,309.8,598.3,312.6,598.9L312.6,598.9z" ] []
            , Svg.path [ class "st6", d "M322.5,559.5c-0.8-0.3-1.6-0.7-2.4-1C320.9,558.9,321.7,559.2,322.5,559.5z M315.8,556.3 M315.4,556.3 l-0.6-0.6C315,555.9,315.2,556.1,315.4,556.3z M317.5,557.5c-0.2-0.1-0.4-0.3-0.6-0.4C317.1,557.2,317.3,557.3,317.5,557.5z M341.2,469.4c-0.1-0.1-0.3-0.1-0.4-0.2C340.9,469.3,341.1,469.3,341.2,469.4z M337.9,468.9c0-0.1,0-0.3,0-0.4 c0.2,0.1,0.3,0.3,0.5,0.4C338.2,468.9,338,468.9,337.9,468.9z" ] []
            , Svg.path [ class "st8", d "M333.9,612.7c3.2-0.3,6.4-0.6,9.3-1.6c1-0.4,2.2-0.4,3.3-0.7c2.6-0.8,5.2-1.7,7.6-2.7c2.6-1.1,5.3-2.3,7.6-3.7 c3.3-2,6.5-4.3,8.6-7.4c0.3-0.5,0.7-1,1.1-1.4c0.2-0.2,0.6-0.3,1-0.4c0.1,0.3,0.3,0.7,0.2,0.9c-0.6,1.1-1.3,2.3-2.2,3.3 c-2.7,3.2-6.3,5.6-10.3,7.7c-2.3,1.2-4.6,2.6-7,3.7c-3,1.4-6.3,2.6-9.8,3.2c-2.6,0.5-5.4,0.8-8,1.2c-0.5,0.1-1,0-1.5,0 c-0.3,0-0.6,0.1-0.9,0.3c-0.1,0-0.3,0-0.4,0c-0.5-0.1-1.1-0.2-1.7-0.2c-3.5-0.1-6.9-0.1-10.4-0.4c-6.1-0.5-12.2-1.4-18.1-3 c-3.9-1-7.7-2.3-11.2-4.1c-3.9-2-7-4.8-9-8.2c-0.6-1.1-1.1-2.2-1.6-3.4c-0.2-0.4-0.5-1.7,0.2-1.6c0,0,9.2,10.2,11.3,10.9 c0.6,0.2,2.2,0.9,2.4,0.9c2.4,0.8,4.5,1.7,6.8,2.4c0.5,0.2,0.9,0.5,1.5,0.5c0.1,0,0.2,0.3,0.3,0.4c0.4,0.1,0.8,0.3,1.2,0.4 c0.4,0,0.7,0.1,1.1,0.2s0.7,0.1,1.1,0.2l0.6,0.1c0.7,0.2,1.4,0.3,2,0.5l0.6,0.1c0.5,0.1,1,0.2,1.6,0.3c0.6,0.1,1.2,0.1,1.7,0.2 c0.2,0.1,0.5,0.3,0.7,0.4c2.4,0.3,4.7,0.6,7.2,0.8c0.2,0,0.5-0.1,0.8-0.2l0.6,0.1c0.8,0.1,1.5,0.1,2.2,0.2c0.3,0,0.6,0.1,0.9,0.1 c0.9,0,1.9,0,2.8,0c0.3,0,0.6,0,0.9,0.1c1.3-0.1,2.6-0.2,3.9-0.2C333.3,612.7,333.6,612.7,333.9,612.7L333.9,612.7z" ] []
            , Svg.path [ class "st4", d "M281.3,595.4c-0.8-0.1-0.8,0.2-0.6,0.6c0.5,1.1,1,2.3,1.6,3.4c2,3.4,5,6.2,9,8.2c3.5,1.8,7.3,3.1,11.2,4.1 c5.9,1.6,12,2.5,18.1,3c3.5,0.3,6.9,0.3,10.4,0.4c0.5,0,1.1,0.1,1.7,0.2c-0.2,0.1-0.5,0.2-0.8,0.2c-7.1,0.2-14.3-0.6-21.3-1.6 c-2.2-0.3-4.3-0.8-6.4-1.3c-2.2-0.6-4.5-1.1-6.7-1.9c-3-1.1-6-2.2-8.6-3.9c-3-1.9-5.1-4.2-6.9-6.9c-0.9-1.3-1.3-2.8-1.8-4.2 c-0.1-0.3,0.3-0.6,0.4-0.9C280.7,595,281,595.2,281.3,595.4L281.3,595.4z" ] []
            , Svg.path [ class "st5", d "M344.7,563.3c-0.2,0.1-0.5,0.2-0.7,0.3C344.3,563.4,344.5,563.4,344.7,563.3z M339.3,563l-0.4-0.1L339.3,563z" ] []
            , Svg.path [ class "st0", d "M316.2,580.5c-0.3-0.2-0.7-0.5-1.1-0.7C315.4,580.1,315.8,580.3,316.2,580.5z" ] []
            , Svg.path [ class "st2", d "M332.9,620.1c-3.9-0.2-7.9-0.3-11.8-0.6c-3.2-0.2-6.5-0.4-9.7-1c-4-0.7-7.9-1.4-11.7-2.7 c-3.2-1-6.3-2.3-9.2-3.9c-2.8-1.5-5.2-3.4-7-5.7c-1.2-1.5-1.9-3.3-2.6-4.9c-0.6-1.4-1.1-2.8-1.3-4.2c-0.3-2-0.5-3.9-0.4-5.9 c0.2-2.2,0.7-4.3,1.2-6.5c0.3-1,0.8-2,1.3-3c0,0.4,0,0.9,0.1,1.3c0,2.2-0.2,4.5,0.9,6.7c0.6,1.2,1.7,2.3,2.2,3.5 c0.8,2.2,2.9,3.5,4.7,4.9c3.9,2.9,8.9,4.1,13.9,5.2c2.7,0.6,5.5,1.2,8.3,1.7c3.4,0.7,6.9,1.3,10.3,1.9l6.2,0.7c0.8,0,1.5,0,2.3-0.1 c0.3,0,2.7-0.4,3.6,0l0.7,0.1c0.5,0.1,1.1,0.2,1.7,0.3c-0.8,1.6-1.1,3.9-2.8,5.2c-0.3,0-10.4,0-11.2-0.1c0,0-13.9-1.6-15.3-2 c-1.1-0.3-5.8-2.1-6.6-2.4l-6.8-2.1c-0.6-0.2-1.1-0.5-1.6-0.7c-1.6-1.1-3.2-2.3-4.8-3.4l-0.1,0l0,0c-0.1-0.2-0.2-0.5-0.4-0.7 c-1.3-1.7-2.6-3.4-4-5.1c-0.2-0.3-0.6-0.5-0.9-0.7c0,0,0-0.1-0.1-0.2c-0.1-0.1-0.2-0.2-0.4-0.4l0,0c-0.3-0.2-0.5-0.4-0.8-0.6 c-0.2,0.3-0.5,0.7-0.4,0.9c0.5,1.4,0.9,2.9,1.8,4.2c1.8,2.6,3.9,5,6.9,6.9c2.7,1.6,5.6,2.9,8.6,3.9c2.2,0.8,4.4,1.3,6.7,1.9 c2.1,0.5,4.3,1,6.4,1.3c7.1,1,14.2,1.7,21.3,1.6c0.3,0,0.5-0.2,0.8-0.2c0.1,0,0.3,0,0.4,0c0.6,0.3,0.6,0.7,0.5,1.2 C333.3,617.6,333.1,618.9,332.9,620.1L332.9,620.1z" ] []
            , Svg.path [ class "st3", d "M321.9,607c-3.4-0.6-6.9-1.3-10.3-1.9c-2.8-0.5-5.5-1.1-8.3-1.7c-4.9-1.1-9.9-2.3-13.9-5.2 c-1.9-1.4-3.9-2.8-4.7-4.9c-0.5-1.2-1.6-2.3-2.2-3.5c-1.1-2.2-0.9-4.4-0.9-6.7c0-0.4,0-0.9-0.1-1.3c1.2-2.8,2.5-5.6,4.7-8 c1.8-2,3.5-4,5.3-6c1.1-1.2,2.3-2.4,3.5-3.6c0.2-0.2,0.5-0.4,0.8-0.6c0,0,0.1,0.1,0.1,0c-0.6,0.7-1.1,1.4-1.7,2.1 c-2.7,3-5.6,6-8.2,9.2c-1.1,1.3-2,2.9-2.5,4.5c-0.6,1.9-0.8,3.9-0.9,5.9c-0.1,0.8-0.4,1.8,0.3,2.7c0.2,0.2,0.1,0.5,0.1,0.7 c-0.1,0.8,0.8,1.2,1.8,1.1c1.1-0.1,2.2,0.1,2.9,1.1c0.4,0.6,0.6,1.3,1,1.9c1.3,2.3,3.3,3.8,5.9,5c5.1,2.4,10.6,3.6,16.1,4.7 c2.5,0.5,5,1.1,7.5,1.6c2.1,0.4,3.3,1.2,3.8,2.9C322,606.9,322,606.9,321.9,607L321.9,607z" ] []
        ]
    ]
